package controllers

import (
	"net/http"

	"code.locsi.com/locsi/api/models"

	"github.com/gin-gonic/gin"
)

// POST /podcast-series
// Create new Podcast Series resource
func CreatePodcastSeries(c *gin.Context) {
	// Validate input
	var input models.PodcastSeries
	if err := c.ShouldBindJSON(&input); err != nil {
		c.JSON(http.StatusBadRequest, gin.H{"error": err.Error()})
		return
	}

	// Create Podcast Series
	if err := models.DB.Create(&input).Error; err != nil {
		c.JSON(http.StatusBadRequest, gin.H{"error": err.Error()})
		return
	}

	c.JSON(http.StatusOK, input)
}

// GET /podcast-series/:id
// Get a Podcast Series resource
func GetPodcastSeries(c *gin.Context) {
	// Get model if exist
	var PodcastSeries models.PodcastSeries
	if err := models.DB.Preload("Categories").Where("id = ?", c.Param("id")).First(&PodcastSeries).Error; err != nil {
		c.JSON(http.StatusBadRequest, gin.H{"error": "Record not found!"})
		return
	}

	/* 				PodcastEpisodeStruct{"https://lexfridman.com/?p=5393", "#359 – Andrew Strominger: Black Holes, Quantum Gravity, and Theoretical Physics", "Lex Fridman Podcast", "Feb 15, 2023", "2:25:03", "Bhaskar Sunkara is a democratic socialist, political writer, founding editor of Jacobin, president of The Nation, and author of The Socialist Manifesto. Please support this podcast by checking out our sponsors: – House of Macadamias: https://houseofmacadamias.com/lex and use code LEX to get 20% of your first order – Linode: https://linode.com/lex to get $100 free credit – Onnit: https://lexfridman.com/onnit to get up to 10% off – InsideTracker: https://insidetracker.com/lex to get 20% off – ExpressVPN: https://expressvpn.com/lexpod to get 3 months free EPISODE LINKS: Bhaskar’s Twitter: https://twitter.com/sunraysunray Jacobin: https://jacobin.com Jacobin’s Twitter: https://twitter.com/jacobin The Nation: https://thenation.com The Socialist Manifesto (book): https://amzn.to/3hKpt2p PODCAST INFO: Podcast website: https://lexfridman.com/podcast Apple Podcasts: https://apple.co/2lwqZIr Spotify: https://spoti.fi/2nEwCF8 RSS: https://lexfridman.com/feed/podcast/ YouTube Full Episodes: https://youtube.com/lexfridman YouTube Clips: https://youtube.com/lexclips SUPPORT & CONNECT: – Check out the sponsors above, it’s the best way to support this podcast – Support on Patreon: https://www.patreon.com/lexfridman – Twitter: https://twitter.com/lexfridman – Instagram: https://www.instagram.com/lexfridman – LinkedIn: https://www.linkedin.com/in/lexfridman – Facebook: https://www.facebook.com/lexfridman – Medium: https://medium.com/@lexfridman OUTLINE: Here’s the timestamps for the episode. On some podcast players you should be able to click the timestamp to jump to that time. (00:00) – Introduction (13:24) – Socialism (31:54) – Communism (58:31) – Class struggle (1:09:33) – Quality of life (1:17:29) – Unions (1:29:57) – Corruption (1:43:15) – Freedom of speech (1:51:38) – War (1:59:24) – Karl Marx (2:13:03) – Socialist vision (2:18:28) – AI and socialism (2:23:26) – Socialist policies (2:48:45) – Billionaires (2:54:43) – Bernie Sanders (3:05:10) – AOC (3:17:11) – 2024 presidential election (3:22:05) – China (3:31:06) – Jacobin (3:38:35) – The Socialist Manifesto (3:45:55) – Advice for young people (3:49:28) – Meaning of life", "https://cdn.player.fm/images/38011093/series/tXl33Iu1sb4pl2VB/512.png", "#359 – Andrew Strominger: Black Holes, Quantum Gravity, and Theoretical Physics", "https://media.blubrry.com/takeituneasy/content.blubrry.com/takeituneasy/lex_ai_andrew_strominger.mp3"},
	 */
	c.JSON(http.StatusOK, PodcastSeries)
}

// GET /podcast-series/:id/episodes
// Get Podcast Episodes associated with a Podcast Series
func GetPodcastSeriesEpisodes(c *gin.Context) {
	// Get model if it exists
	var PodcastEpisodes []models.PodcastEpisode
	if err := models.DB.Where("podcast_series_id = ?", c.Param("id")).Order("date_published desc").Find(&PodcastEpisodes).Error; err != nil {
		c.JSON(http.StatusBadRequest, gin.H{"error": "Record not found!"})
		return
	}

	c.JSON(http.StatusOK, PodcastEpisodes)
}
